@@ -1,7 +1,8 @@
+from django.utils.deprecation import MiddlewareMixin
 from django_journal import journal
 
 
-class JournalMiddleware(object):
+class JournalMiddleware(MiddlewareMixin):
     '''Add record and error_record methods to the request object to log
        current user and current REMOTE_ADRESS.
 
