@@ -122,8 +122,8 @@ class StringData(models.Model):
        content:
            the string value of the data
     '''
-    journal = models.ForeignKey(Journal, verbose_name=_('journal entry'))
-    tag = models.ForeignKey(Tag, verbose_name=_('tag'))
+    journal = models.ForeignKey(Journal, verbose_name=_('journal entry'), on_delete=models.CASCADE)
+    tag = models.ForeignKey(Tag, verbose_name=_('tag'), on_delete=models.CASCADE)
     content = models.TextField(verbose_name=_('content'))
 
     class Meta:
@@ -142,9 +142,9 @@ class ObjectData(models.Model):
        content_object:
            the object value of the data
     '''
-    journal = models.ForeignKey(Journal, verbose_name=_('journal entry'))
-    tag = models.ForeignKey(Tag, verbose_name=_('tag'))
-    content_type = models.ForeignKey('contenttypes.ContentType',
+    journal = models.ForeignKey(Journal, verbose_name=_('journal entry'), on_delete=models.CASCADE)
+    tag = models.ForeignKey(Tag, verbose_name=_('tag'), on_delete=models.CASCADE)
+    content_type = models.ForeignKey('contenttypes.ContentType', on_delete=models.CASCADE,
             verbose_name=_('content type'))
     object_id = models.PositiveIntegerField(db_index=True,
             verbose_name=_('object id'))
